'use strict';

const Gettext = imports.gettext;
const {  Gio, GObject, St } = imports.gi;
const PopupMenu = imports.ui.popupMenu;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Docker = Me.imports.lib.docker;
const Domain = Gettext.domain(Me.metadata.uuid);
const _ = Domain.gettext;
const ngettext = Domain.ngettext;


var Container_Menu = GObject.registerClass(
	class Container_Menu extends PopupMenu.PopupSubMenuMenuItem {
		_init(name, status) {
			super._init(name)
			this._set_status(status);

			let item;
			switch (status){
				case "running":
					item = new PopupMenu.PopupMenuItem(_("Exec"));
					item.connect('activate', () => Docker.run_command("exec", name));
					this.menu.addMenuItem(item);

					item = new PopupMenu.PopupMenuItem(_("Pause"));
					item.connect('activate', () => Docker.run_command("pause", name));
					this.menu.addMenuItem(item);

					item = new PopupMenu.PopupMenuItem(_("Stop"));
					item.connect('activate', () => Docker.run_command("stop", name));
					this.menu.addMenuItem(item);
				break;

				case "paused":
					item = new PopupMenu.PopupMenuItem(_("Unpause"));
					item.connect('activate', () => Docker.run_command("unpause", name));
					this.menu.addMenuItem(item);

					item = new PopupMenu.PopupMenuItem(_("Stop"));
					item.connect('activate', () => Docker.run_command("stop", name));
					this.menu.addMenuItem(item);
				break;

				default:
					item = new PopupMenu.PopupMenuItem(_("Start"));
					item.connect('activate', () => Docker.run_command("start", name));
					this.menu.addMenuItem(item);

					item = new PopupMenu.PopupMenuItem(_("Start interactive"));
					item.connect('activate', () => Docker.run_command("start i", name));
					this.menu.addMenuItem(item);
			}

			item = new PopupMenu.PopupMenuItem(_("Restart"));
			item.connect('activate', () => Docker.run_command("restart", name));
			this.menu.addMenuItem(item);

			if (status == "running") {
			}

			item = new PopupMenu.PopupMenuItem(_("Remove"));
			item.connect('activate', () => Docker.run_command("rm", name));
			this.menu.addMenuItem(item);
		}

		_set_status(status) {
			let icon = new St.Icon({
				icon_name: 'media-record-symbolic',
				style_class: 'stop',
				icon_size: '14'
			});

			if (status == "running") {
				icon.style_class = 'running';
			}

			this.actor.insert_child_at_index(icon,1);
		}
	}
)